summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorMichael Brown2020-11-05 20:08:48 +0100
committerMichael Brown2020-11-05 20:13:52 +0100
commitbe1c87b72237f633c4f4b05bcb133acf2967d788 (patch)
treeadc9bc36da62d55f0f1f5708af7c66d1cc3af949 /src/include
parent[efi] Retain a long-lived reference to the EFI_PCI_IO_PROTOCOL instance (diff)
downloadipxe-be1c87b72237f633c4f4b05bcb133acf2967d788.tar.gz
ipxe-be1c87b72237f633c4f4b05bcb133acf2967d788.tar.xz
ipxe-be1c87b72237f633c4f4b05bcb133acf2967d788.zip
[malloc] Rename malloc_dma() to malloc_phys()
The malloc_dma() function allocates memory with specified physical alignment, and is typically (though not exclusively) used to allocate memory for DMA. Rename to malloc_phys() to more closely match the functionality, and to create name space for functions that specifically allocate and map DMA-capable buffers. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/ipxe/malloc.h32
1 files changed, 14 insertions, 18 deletions
diff --git a/src/include/ipxe/malloc.h b/src/include/ipxe/malloc.h
index 1878978fd..180ca001d 100644
--- a/src/include/ipxe/malloc.h
+++ b/src/include/ipxe/malloc.h
@@ -14,7 +14,7 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
/*
* Prototypes for the standard functions (malloc() et al) are in
* stdlib.h. Include <ipxe/malloc.h> only if you need the
* non-standard functions, such as malloc_dma().
*
*/
#include <stdlib.h>
@@ -32,20 +32,18 @@ extern void mpopulate ( void *start, size_t len );
extern void mdumpfree ( void );
/**
- * Allocate memory for DMA
+ * Allocate memory with specified physical alignment and offset
*
* @v size Requested size
* @v align Physical alignment
* @v offset Offset from physical alignment
* @ret ptr Memory, or NULL
*
- * Allocates physically-aligned memory for DMA.
- *
* @c align must be a power of two. @c size may not be zero.
*/
-static inline void * __malloc malloc_dma_offset ( size_t size,
- size_t phys_align,
- size_t offset ) {
+static inline void * __malloc malloc_phys_offset ( size_t size,
+ size_t phys_align,
+ size_t offset ) {
void * ptr = alloc_memblock ( size, phys_align, offset );
if ( ptr && size )
VALGRIND_MALLOCLIKE_BLOCK ( ptr, size, 0, 0 );
@@ -53,32 +51,30 @@ static inline void * __malloc malloc_dma_offset ( size_t size,
}
/**
- * Allocate memory for DMA
+ * Allocate memory with specified physical alignment
*
* @v size Requested size
* @v align Physical alignment
* @ret ptr Memory, or NULL
*
- * Allocates physically-aligned memory for DMA.
- *
* @c align must be a power of two. @c size may not be zero.
*/
-static inline void * __malloc malloc_dma ( size_t size, size_t phys_align ) {
- return malloc_dma_offset ( size, phys_align, 0 );
+static inline void * __malloc malloc_phys ( size_t size, size_t phys_align ) {
+ return malloc_phys_offset ( size, phys_align, 0 );
}
/**
* Free memory allocated with malloc_dma()
*
* @v ptr Memory allocated by malloc_dma(), or NULL
* @v size Size of memory, as passed to malloc_dma()
*
* Memory allocated with malloc_dma() can only be freed with
* free_dma(); it cannot be freed with the standard free().
*
* If @c ptr is NULL, no action is taken.
*/
-static inline void free_dma ( void *ptr, size_t size ) {
+static inline void free_phys ( void *ptr, size_t size ) {
VALGRIND_FREELIKE_BLOCK ( ptr, 0 );
free_memblock ( ptr, size );
}
@@ -14,7 +14,7 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
* Prototypes for the standard functions (malloc() et al) are in
* stdlib.h. Include <ipxe/malloc.h> only if you need the
- * non-standard functions, such as malloc_dma().
+ * non-standard functions, such as malloc_phys().
*
*/
@@ -53,32 +51,30 @@ static inline void * __malloc malloc_dma_offset ( size_t size,
}
/**
- * Free memory allocated with malloc_dma()
+ * Free memory allocated with malloc_phys()
*
@@ -53,32 +51,30 @@ static inline void * __malloc malloc_dma_offset ( size_t size,
*
- * @v ptr Memory allocated by malloc_dma(), or NULL
- * @v size Size of memory, as passed to malloc_dma()
+ * @v ptr Memory allocated by malloc_phys(), or NULL
+ * @v size Size of memory, as passed to malloc_phys()
*
@@ -53,32 +51,30 @@ static inline void * __malloc malloc_dma_offset ( size_t size,
*
- * Memory allocated with malloc_dma() can only be freed with
- * free_dma(); it cannot be freed with the standard free().
+ * Memory allocated with malloc_phys() can only be freed with
+ * free_phys(); it cannot be freed with the standard free().
*
* If @c ptr is NULL, no action is taken.